@@ -23,7 +23,7 @@
 #ifndef PSYCHOSYNTH_CLI_H
 #define PSYCHOSYNTH_CLI_H
 
-#include <psynth/psynth/psynth_app.hpp>
+#include <psynth/app/psynth_app.hpp>
 #include <psynth/version.hpp>
 
 class psychosynth_cli : public psynth::psynth_app
@@ -39,7 +39,7 @@ private:
     
     void print_help ();
     void print_version ();
-    void prepare (psynth::arg_parser& arg_parser);
+    void prepare (psynth::base::arg_parser& arg_parser);
     void init ();
 
     int execute ();
