@@ -25,6 +25,7 @@
 #include "gui3d/conf_window.hpp"
 
 using namespace psynth;
+using namespace psynth::base;
 using namespace CEGUI;
 using namespace std;
 
@@ -73,9 +74,9 @@ bool path_conf_window::on_apply (const CEGUI::EventArgs &e)
 {
     m_conf.clear_childs();
 
-    for (int i = 0; i < m_listbox->getItemCount(); ++i) {
+    for (size_t i = 0; i < m_listbox->getItemCount(); ++i) {
 	string val = m_listbox->getItemFromIndex(i)->getText().c_str();
-	m_conf.get_child(string("path") + itoa(i, 10)).set(val);
+	m_conf.child(string("path") + base::itoa(i, 10)).set(val);
     }
     
     m_conf.nudge();
@@ -98,7 +99,10 @@ void path_conf_window::populate ()
     ItemEntry* item;
     std::string val;
     
-    for (conf_node::iterator iter = m_conf.begin(); iter != m_conf.end(); ++iter) {
+    for (base::conf_node::iterator iter = m_conf.begin();
+	 iter != m_conf.end();
+	 ++iter)
+    {
 	iter->get(val);
 	item = static_cast<ItemEntry*>(wmgr.createWindow("TaharezLook/ListboxItem"));
 	item->setText(val);
@@ -175,7 +179,7 @@ CEGUI::FrameWindow* path_conf_window::create_window ()
     return window;
 }
 
-Window* output_conf_window_simple::create_window (psynth::conf_node& node)
+Window* output_conf_window_simple::create_window (psynth::base::conf_node& node)
 {
     m_node = &node;
     
@@ -195,7 +199,7 @@ Window* output_conf_window_simple::create_window (psynth::conf_node& node)
     label->setText(m_name);
 
     string str_val;
-    node.get_path(m_conf_path).get(str_val);
+    node.path(m_conf_path).get(str_val);
 
 /*
   cout << "new device val ("<< node.getPath(m_conf_path).getPathName() << ": " << str_val << endl;
@@ -217,7 +221,7 @@ void conf_window::start_output_conf_window (const std::string& out)
 
     if (i != m_map.end()) {
 	m_out_win = i->second->create_output_conf_window ();
-	m_out_cegui_win = m_out_win->create_window (m_psynth_conf.get_child (out));
+	m_out_cegui_win = m_out_win->create_window (m_psynth_conf.child (out));
     }
 }
 
@@ -253,7 +257,7 @@ CEGUI::Window* conf_window::create_audio_settings_window ()
     label->setText("Sample rate:");
 
     int int_val;
-    m_psynth_conf.get_child ("sample_rate").get(int_val);
+    m_psynth_conf.child ("sample_rate").get(int_val);
     m_srate = static_cast<Editbox*>(wmgr.createWindow("TaharezLook/Editbox"));
     st->addChildWindow(m_srate);
     m_srate->setPosition(UVector2(UDim(0.5, 3), UDim(0, 6)));
@@ -269,7 +273,7 @@ CEGUI::Window* conf_window::create_audio_settings_window ()
     label->setSize(UVector2(UDim(0.5, -9), UDim(0, 20)));
     label->setText("Buffer size:");
 
-    m_psynth_conf.get_child ("block_size").get(int_val);
+    m_psynth_conf.child ("block_size").get(int_val);
     m_bufsize = static_cast<Editbox*>(wmgr.createWindow("TaharezLook/Editbox"));
     st->addChildWindow(m_bufsize);
     m_bufsize->setPosition(UVector2(UDim(0.5, 3), UDim(0, 30)));
@@ -285,7 +289,7 @@ CEGUI::Window* conf_window::create_audio_settings_window ()
     label->setSize(UVector2(UDim(0.5, -9), UDim(0, 20)));
     label->setText("Channels:");
 
-    m_psynth_conf.get_child ("num_channels").get(int_val);
+    m_psynth_conf.child ("num_channels").get(int_val);
     m_channels = static_cast<Editbox*>(wmgr.createWindow("TaharezLook/Editbox"));
     st->addChildWindow(m_channels);
     m_channels->setPosition(UVector2(UDim(0.5, 3), UDim(0, 54)));
@@ -309,7 +313,7 @@ CEGUI::Window* conf_window::create_audio_settings_window ()
     label->setText("Output:");
 
     string str_val;
-    m_psynth_conf.get_child ("output").get(str_val);
+    m_psynth_conf.child ("output").get(str_val);
     m_output = dynamic_cast<Combobox*>(wmgr.createWindow("TaharezLook/Combobox"));
     m_output->setPosition(UVector2(UDim(0.5, 3), UDim(0, 6)));
     m_output->setSize(UVector2(UDim(0.5, -9), UDim(0, 90)));
@@ -389,7 +393,7 @@ CEGUI::Window* conf_window::create_video_settings_window ()
     label->setText("Width:");
 
     int int_val;
-    m_gui_conf.get_child ("screen_width").get(int_val);
+    m_gui_conf.child ("screen_width").get(int_val);
     m_sc_width = static_cast<Editbox*>(wmgr.createWindow("TaharezLook/Editbox"));
     st->addChildWindow(m_sc_width);
     m_sc_width->setPosition(UVector2(UDim(0, 6), UDim(0, 25)));
@@ -405,7 +409,7 @@ CEGUI::Window* conf_window::create_video_settings_window ()
     label->setSize(UVector2(UDim(0.5, -9), UDim(0, 20)));
     label->setText("Height:");
 
-    m_gui_conf.get_child ("screen_height").get(int_val);
+    m_gui_conf.child ("screen_height").get(int_val);
     m_sc_height = static_cast<Editbox*>(wmgr.createWindow("TaharezLook/Editbox"));
     st->addChildWindow(m_sc_height);
     m_sc_height->setPosition(UVector2(UDim(0.5, 3), UDim(0, 25)));
@@ -413,7 +417,7 @@ CEGUI::Window* conf_window::create_video_settings_window ()
     m_sc_height->setValidationString("\\d*");
     m_sc_height->setText(itoa(int_val, 10));
 
-    m_gui_conf.get_child ("fullscreen").get(int_val);
+    m_gui_conf.child ("fullscreen").get(int_val);
     m_fullscreen = static_cast<Checkbox*>(wmgr.createWindow("TaharezLook/Checkbox"));
     st->addChildWindow(m_fullscreen);
     m_fullscreen->setText("Fullscreen");
@@ -431,7 +435,7 @@ CEGUI::Window* conf_window::create_video_settings_window ()
     but->subscribeEvent(PushButton::EventClicked, 
 			Event::Subscriber(&conf_window::on_window_apply_press, this));
 
-    m_gui_conf.get_child ("fps").get(int_val);
+    m_gui_conf.child ("fps").get(int_val);
     m_fpslabel = wmgr.createWindow("TaharezLook/StaticText");
     window->addChildWindow(m_fpslabel);
     m_fpslabel->setProperty("FrameEnabled", "false");
@@ -508,7 +512,7 @@ bool conf_window::on_generic (const CEGUI::EventArgs &e)
 bool conf_window::on_output_change (const CEGUI::EventArgs &e)
 {
     string new_val = m_output->getText().c_str();
-    m_psynth_conf.get_child ("output").set(new_val);
+    m_psynth_conf.child ("output").set(new_val);
 
     Window* st = NULL;
     if (m_out_cegui_win) {
@@ -535,10 +539,10 @@ bool conf_window::on_audio_apply_press (const CEGUI::EventArgs &e)
     int nc = atoi(m_channels->getText().c_str());
     string out = m_output->getText().c_str();
     
-    m_psynth_conf.get_child ("sample_rate").set(sr);
-    m_psynth_conf.get_child ("block_size").set(bs);
-    m_psynth_conf.get_child ("num_channels").set(nc);
-    m_psynth_conf.get_child ("output").set(out);
+    m_psynth_conf.child ("sample_rate").set(sr);
+    m_psynth_conf.child ("block_size").set(bs);
+    m_psynth_conf.child ("num_channels").set(nc);
+    m_psynth_conf.child ("output").set(out);
     if (m_out_win)
 	m_out_win->apply();
     
@@ -551,7 +555,7 @@ bool conf_window::on_fps_change (const CEGUI::EventArgs &e)
 {
     int val = m_fps->getScrollPosition() + 20;
     
-    m_gui_conf.get_child ("fps").set(val);
+    m_gui_conf.child ("fps").set(val);
     m_fpslabel->setText(CEGUI::String("FPS: ") + itoa(val, 10));
     
     return true;
@@ -563,9 +567,9 @@ bool conf_window::on_window_apply_press (const CEGUI::EventArgs &e)
     int sh = atoi(m_sc_height->getText().c_str());
     int fs = m_fullscreen->isSelected();
 
-    m_gui_conf.get_child ("screen_width").set(sw);
-    m_gui_conf.get_child ("screen_height").set(sh);
-    m_gui_conf.get_child ("fullscreen").set(fs);
+    m_gui_conf.child ("screen_width").set(sw);
+    m_gui_conf.child ("screen_height").set(sh);
+    m_gui_conf.child ("fullscreen").set(fs);
 
     m_gui_conf.nudge();
     
@@ -595,9 +599,9 @@ CEGUI::FrameWindow* conf_window::create_window ()
     return window;
 }
 
-conf_window::conf_window (psynth::conf_node& gui_conf,
-			  psynth::conf_node& psynth_conf) :
-    m_samples_win(psynth_conf.get_path ("file_manager.samples")),
+conf_window::conf_window (psynth::base::conf_node& gui_conf,
+			  psynth::base::conf_node& psynth_conf) :
+    m_samples_win(psynth_conf.path ("file_manager.samples")),
     m_gui_conf(gui_conf),
     m_psynth_conf(psynth_conf)
 {
