@@ -31,7 +31,7 @@ class default_selector_populator
     selector_window* m_selector;
 
     void populate_samples (selector_window::category* cat);
-    void on_samples_conf_nudge (psynth::conf_node& conf);
+    void on_samples_conf_nudge (psynth::base::conf_node& conf);
     
 public:
     void populate (selector_window* sel);
