@@ -30,7 +30,7 @@
 
 #include <psynth/base/logger.hpp>
 
-#include <psynth/node/node_types.hpp>
+#include <psynth/graph/node_types.hpp>
 
 using namespace std;
 using namespace Ogre;
@@ -406,7 +406,7 @@ void element_manager::handle_add_node (world_node& obj)
 	obj.add_listener(elem);
     }
     else
-      logger::self () ("gui3d", psynth::log::warning, "Could not create element.");
+	base::logger::self () ("gui3d", base::log::warning, "Could not create element.");
 }
 
 void element_manager::handle_delete_node (world_node& obj)
