@@ -60,8 +60,9 @@
 
 using namespace Ogre;
 using namespace std;
-using namespace psynth;
 
+using namespace psynth;
+using namespace psynth::base;
 
 psychosynth_3d::psychosynth_3d()
     : m_must_quit (0)
@@ -102,69 +103,69 @@ void psychosynth_3d::print_version ()
 
 }
 
-void psychosynth_3d::prepare (psynth::arg_parser& arg_parser)
+void psychosynth_3d::prepare (arg_parser& arg_parser)
 {
-    conf_node& conf = config::self ().get_child ("psynth3d");
+    conf_node& conf = config::self ().child ("psynth3d");
     
     arg_parser.add ('W', "width",
-		    new option_conf<int>(conf.get_child ("screen_width")));
+		    new option_conf<int>(conf.child ("screen_width")));
     arg_parser.add ('H', "height",
-		    new option_conf<int>(conf.get_child ("screen_height")));
+		    new option_conf<int>(conf.child ("screen_height")));
     arg_parser.add ('f', "fullscreen",
-		    new option_conf_value<int>(1, conf.get_child ("fullscreen")));
+		    new option_conf_value<int>(1, conf.child ("fullscreen")));
     arg_parser.add ('w', "window",
-		    new option_conf_value<int>(0, conf.get_child ("fullscreen")));
+		    new option_conf_value<int>(0, conf.child ("fullscreen")));
     arg_parser.add ('F', "fps",
-		    new option_conf<int>(conf.get_child ("fps")));
+		    new option_conf<int>(conf.child ("fps")));
 }
 
 int psychosynth_3d::execute()
 {
-    logger::self () ("gui", psynth::log::info, "Loading settings.");
+    logger::self () ("gui", log::info, "Loading settings.");
      
-    conf_node& conf = config::self ().get_child ("psynth3d");
+    conf_node& conf = config::self ().child ("psynth3d");
     setup_settings (conf);
     
-    logger::self () ("gui", psynth::log::info, "Initializing Ogre.");
+    logger::self () ("gui", log::info, "Initializing Ogre.");
     setup_ogre (conf);
-    logger::self () ("gui", psynth::log::info, "Initializing OIS.");
+    logger::self () ("gui", log::info, "Initializing OIS.");
     setup_input ();
-    logger::self () ("gui", psynth::log::info, "Initializing synthesizer.");
+    logger::self () ("gui", log::info, "Initializing synthesizer.");
     setup_synth ();
 #ifdef PSYNTH_HAVE_OSC
-    logger::self () ("gui", psynth::log::info, "Initializing networking.");
+    logger::self () ("gui", log::info, "Initializing networking.");
     setup_net ();
 #endif
-    logger::self () ("gui", psynth::log::info, "Initializing scene.");
+    logger::self () ("gui", log::info, "Initializing scene.");
     setup_world ();
-    logger::self () ("gui", psynth::log::info, "Initializing CEGUI.");
+    logger::self () ("gui", log::info, "Initializing CEGUI.");
     setup_gui ();
-    logger::self () ("gui", psynth::log::info, "Initializing GUI elements.");
+    logger::self () ("gui", log::info, "Initializing GUI elements.");
     setup_menus ();
 		
     m_ogre->startRendering();
 
-    logger::self () ("gui", psynth::log::info, "Closing GUI elements.");
+    logger::self () ("gui", log::info, "Closing GUI elements.");
     close_menus ();
-    logger::self () ("gui", psynth::log::info, "Closing CEGUI.");
+    logger::self () ("gui", log::info, "Closing CEGUI.");
     close_gui ();
 #ifdef PSYNTH_HAVE_OSC
-    logger::self () ("gui", psynth::log::info, "Closing networking.");
+    logger::self () ("gui", log::info, "Closing networking.");
     close_net ();
 #endif
-    logger::self () ("gui", psynth::log::info, "Closing scene.");
+    logger::self () ("gui", log::info, "Closing scene.");
     close_world ();
-    logger::self () ("gui", psynth::log::info, "Closing synthesizer.");
+    logger::self () ("gui", log::info, "Closing synthesizer.");
     close_synth ();
-    logger::self () ("gui", psynth::log::info, "Closing OIS.");
+    logger::self () ("gui", log::info, "Closing OIS.");
     close_input ();
-    logger::self () ("gui", psynth::log::info, "Closing Ogre.");
+    logger::self () ("gui", log::info, "Closing Ogre.");
     close_ogre ();
 
-    logger::self () ("gui", psynth::log::info, "Storing settings.");
+    logger::self () ("gui", log::info, "Storing settings.");
     try {
 	conf.save();
-    } catch (psynth::exception& error) {
+    } catch (psynth::base::exception& error) {
 	error.log ();
     } catch (std::exception& error) {
 	logger::self () ("gui", log::error, error.what ());
@@ -215,59 +216,60 @@ void psychosynth_3d::setup_settings (conf_node& conf)
     try
     {
 #ifdef PSYNTH_HAVE_XML
-	conf.attach_backend (new conf_backend_xml
-			     ((get_config_path() / "psynth3d.xml").file_string ()));
+	conf.set_backend (
+	    new_conf_backend_xml (
+		(get_config_path() / "psynth3d.xml").string ()));
 #endif
 	conf.def_load();
     }
-    catch (psynth::exception& error) {
+    catch (psynth::base::exception& error) {
 	error.log ();
     } catch (std::exception& error) {
 	logger::self () ("gui", log::error, error.what ());
     }
     
-    conf.get_child ("screen_width").def (DEFAULT_SCREEN_WIDTH);
-    conf.get_child ("screen_height").def (DEFAULT_SCREEN_HEIGHT);
-    conf.get_child ("fullscreen").def (DEFAULT_FULLSCREEN);
-    conf.get_child ("fps").def (DEFAULT_FPS);
+    conf.child ("screen_width").def (DEFAULT_SCREEN_WIDTH);
+    conf.child ("screen_height").def (DEFAULT_SCREEN_HEIGHT);
+    conf.child ("fullscreen").def (DEFAULT_FULLSCREEN);
+    conf.child ("fps").def (DEFAULT_FPS);
 	
     /* Is it dangerous to have this set before the gui is initialized? */
     conf.on_nudge.connect
-	(sigc::mem_fun (*this, &psychosynth_3d::on_config_change));
-    conf.get_child ("fps").on_change.connect
-	(sigc::mem_fun (*this, &psychosynth_3d::on_fps_change));
+	(boost::bind (&psychosynth_3d::on_config_change, this, _1));
+    conf.child ("fps").on_change.connect
+	(boost::bind (&psychosynth_3d::on_fps_change, this, _1));
     
 }
 
-void psychosynth_3d::setup_ogre (psynth::conf_node& conf)
+void psychosynth_3d::setup_ogre (conf_node& conf)
 {
     int screen_width;
     int screen_height;
     int fullscreen;
     int fps;
 
-    conf.get_child ("screen_width").get (screen_width);
-    conf.get_child ("screen_height").get (screen_height);
-    conf.get_child ("fullscreen").get (fullscreen);
-    conf.get_child ("fps").get (fps);
+    conf.child ("screen_width").get (screen_width);
+    conf.child ("screen_height").get (screen_height);
+    conf.child ("fullscreen").get (fullscreen);
+    conf.child ("fps").get (fps);
     
     (new LogManager)->createLog
-	((get_config_path() / "gui3d/psynth3d_Ogre.log").file_string (),
+	((get_config_path() / "gui3d/psynth3d_Ogre.log").string (),
 	 false, false, false);
     
-    m_ogre = new Root ((get_data_path() / "gui3d/plugins.cfg").file_string (),
-		       (get_data_path() / "gui3d/ogre.cfg").file_string ());
+    m_ogre = new Root ((get_data_path() / "gui3d/plugins.cfg").string (),
+		       (get_data_path() / "gui3d/ogre.cfg").string ());
         
     ResourceGroupManager& res_mgr = ResourceGroupManager::getSingleton();
-    res_mgr.addResourceLocation (get_data_path ().file_string (),
+    res_mgr.addResourceLocation (get_data_path ().string (),
 				 "FileSystem", "General");
-    res_mgr.addResourceLocation ((get_data_path () / "gui3d/mesh").file_string (),
+    res_mgr.addResourceLocation ((get_data_path () / "gui3d/mesh").string (),
 				 "FileSystem", "General");
-    res_mgr.addResourceLocation ((get_data_path () / "gui3d/texture").file_string (),
+    res_mgr.addResourceLocation ((get_data_path () / "gui3d/texture").string (),
 				 "FileSystem", "General");
-    res_mgr.addResourceLocation ((get_data_path () / "gui3d/material").file_string (),
+    res_mgr.addResourceLocation ((get_data_path () / "gui3d/material").string (),
 				 "FileSystem", "General");
-    res_mgr.addResourceLocation ((get_data_path () / "gui3d/gui").file_string (),
+    res_mgr.addResourceLocation ((get_data_path () / "gui3d/gui").string (),
 				 "FileSystem", "GUI");
 
     if (!m_ogre->restoreConfig() && !m_ogre->showConfigDialog())
@@ -295,7 +297,7 @@ void psychosynth_3d::setup_ogre (psynth::conf_node& conf)
 void psychosynth_3d::setup_input ()
 {
     int fullscreen; /* I prefer not using the singleton here. */
-    config::self ().get_path("psynth3d.fullscreen").get(fullscreen);
+    config::self ().path("psynth3d.fullscreen").get(fullscreen);
     
     OIS::ParamList pl;
     size_t window_hnd = 0;
@@ -326,7 +328,7 @@ void psychosynth_3d::setup_gui ()
 						 false, 3000, m_scene);
     
     m_gui = new CEGUI::System (m_ceguirender, 0, 0, 0, "",
-			       (get_config_path () / "psynth3d_CEGUI.log").file_string ());
+			       (get_config_path () / "psynth3d_CEGUI.log").string ());
 
     CEGUI::SchemeManager::getSingleton().loadScheme("TaharezLook.scheme");
     m_gui->setDefaultMouseCursor("TaharezLook", "MouseArrow");
@@ -423,7 +425,7 @@ void psychosynth_3d::setup_world ()
     node->attachObject(ring1);
     node->setPosition(Vector3(0,0.01,0));
 
-    m_taskmgr = &task_manager::self  ();
+    m_taskmgr = &global_task_manager::self  ();
     m_elemmgr = new element_manager (get_world(), m_scene, m_camera);
     m_camctrl = new camera_controller_default (m_camera);
 
@@ -467,8 +469,8 @@ void psychosynth_3d::setup_menus ()
     m_windowlist->add_window ("ConfWindowButton.imageset",
 			      "ConfWindowButton.layout",
 			      "Configure the program settings.",
-			      new conf_window (config::self ().get_child ("psynth3d"),
-					       config::self ().get_child ("psychosynth")),
+			      new conf_window (config::self ().child ("psynth3d"),
+					       config::self ().child ("psychosynth")),
 			      OIS::KC_UNASSIGNED);
     m_windowlist->add_window ("InfoWindowButton.imageset",
 			      "InfoWindowButton.layout",
@@ -521,17 +523,17 @@ void psychosynth_3d::close_ogre ()
     delete m_ogre;
 }
 
-void psychosynth_3d::on_config_change (psynth::conf_node& conf)
+void psychosynth_3d::on_config_change (conf_node& conf)
 {
     int sc_width;
     int sc_height;
     int sc_fullscreen;
     int fps;
 
-    conf.get_child ("screen_width").get(sc_width);
-    conf.get_child ("screen_height").get(sc_height);
-    conf.get_child ("fullscreen").get(sc_fullscreen);
-    conf.get_child ("fps").get(fps);
+    conf.child ("screen_width").get(sc_width);
+    conf.child ("screen_height").get(sc_height);
+    conf.child ("fullscreen").get(sc_fullscreen);
+    conf.child ("fps").get(fps);
 
     m_timer.force_fps(fps);
     m_window->setFullscreen(sc_fullscreen,
@@ -540,7 +542,7 @@ void psychosynth_3d::on_config_change (psynth::conf_node& conf)
     //m_ogre->reinitialise();
 }
 
-void psychosynth_3d::on_fps_change (psynth::conf_node& conf)
+void psychosynth_3d::on_fps_change (conf_node& conf)
 {
     int fps;
     
